# Increasing Your Data Quality
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/increasing-your-data-quality#introduction)
  * [Fact Sheet Completion Score](https://help.sap.com/docs/leanix/ea/increasing-your-data-quality#fact-sheet-completion-score)
  * [Fact Sheet Subscription](https://help.sap.com/docs/leanix/ea/increasing-your-data-quality#fact-sheet-subscription)
  * [Quality Seal](https://help.sap.com/docs/leanix/ea/increasing-your-data-quality#quality-seal)
  * [Mandatory Attributes](https://help.sap.com/docs/leanix/ea/increasing-your-data-quality#mandatory-attributes)
  * [Data Quality Insights](https://help.sap.com/docs/leanix/ea/increasing-your-data-quality#data-quality-insights)
  * [Surveys](https://help.sap.com/docs/leanix/ea/increasing-your-data-quality#surveys)
  * [Reference Catalog](https://help.sap.com/docs/leanix/ea/increasing-your-data-quality#reference-catalog)
  * [Discoveries and Integrations](https://help.sap.com/docs/leanix/ea/increasing-your-data-quality#discoveries-and-integrations)


Enhance data quality in SAP LeanIX with features like fact sheet completion scores, fact sheet subscriptions, mandatory fields, quality seals, and surveys. Use integrations and discovery tools for accurate, up-to-date data.
